@@ -11,13 +11,13 @@ Querylet::Output - generic output handler for Querlet::Query
 
 =head1 VERSION
 
-version 0.16
+version 0.20
 
- $Id: Output.pm,v 1.1 2004/09/18 19:44:41 rjbs Exp $
+ $Id: Output.pm,v 1.2 2004/09/19 18:18:35 rjbs Exp $
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.20';
 
 =head1 SYNOPSIS
 
@@ -73,7 +73,7 @@ sub import {
 
 	my $handler = $class->handler;
 
-	Querylet::Query->register_handler($type => $handler);
+	Querylet::Query->register_output_handler($type => $handler);
 }
 
 =head1 METHODS
